--------------------------------------------------------------------------------
-- CERN BE-CO-HT
-- Mock Turtle
-- https://gitlab.cern.ch/coht/mockturtle
--------------------------------------------------------------------------------
--
-- unit name:   mt_endpoint_pkg
--
-- description: Global package for the UDP/Ethernet RMQ endpoint.
--
--------------------------------------------------------------------------------
-- Copyright CERN 2014-2018
--------------------------------------------------------------------------------
-- Copyright and related rights are licensed under the Solderpad Hardware
-- License, Version 2.0 (the "License"); you may not use this file except
-- in compliance with the License. You may obtain a copy of the License at
-- http://solderpad.org/licenses/SHL-2.0.
-- Unless required by applicable law or agreed to in writing, software,
-- hardware and materials distributed under this License is distributed on an
-- "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
-- or implied. See the License for the specific language governing permissions
-- and limitations under the License.
--------------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;

use work.wishbone_pkg.all;

package mt_endpoint_pkg is

  constant c_rmq_data_start_offset : integer := 32;

  type t_rmq_ep_tx_config is record
    dst_mac      : std_logic_vector(47 downto 0);
    src_ip       : std_logic_vector(31 downto 0);
    dst_ip       : std_logic_vector(31 downto 0);
    src_port     : std_logic_vector(15 downto 0);
    dst_port     : std_logic_vector(15 downto 0);
    ethertype    : std_logic_vector(15 downto 0);
    is_udp       : std_logic;
    payload_size : std_logic_vector(15 downto 0);
  end record;

  type t_rmq_ep_rx_config is record
    dst_mac          : std_logic_vector(47 downto 0);
    dst_ip           : std_logic_vector(31 downto 0);
    dst_port         : std_logic_vector(15 downto 0);
    ethertype        : std_logic_vector(15 downto 0);
    store_header     : std_logic;
    filter_dst_mac   : std_logic;
    filter_dst_ip    : std_logic;
    filter_dst_port  : std_logic;
    filter_ethertype : std_logic;
    filter_udp       : std_logic;
    filter_raw       : std_logic;
    enable           : std_logic;  -- discard all packets if 0
  end record;

  type t_rmq_ep_rx_header is record
    is_udp     : std_logic;
    is_raw     : std_logic;
    src_mac    : std_logic_vector(47 downto 0);
    dst_mac    : std_logic_vector(47 downto 0);
    ethertype  : std_logic_vector(15 downto 0);
    src_port   : std_logic_vector(15 downto 0);
    dst_port   : std_logic_vector(15 downto 0);
    src_ip     : std_logic_vector(31 downto 0);
    dst_ip     : std_logic_vector(31 downto 0);
    udp_length : std_logic_vector(15 downto 0);
  end record;

  type t_rmq_ep_tx_slot_config_array is
    array(integer range<>) of t_rmq_ep_tx_config;
end mt_endpoint_pkg;
